==> jc-1.4.0.tar.gz: soot/coffi/InnerClasses__5fattribute.c <==
// class soot.coffi.InnerClasses_attribute

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 94d357637b968dda java_lang_StringBuffer
// @dep_class 2910858fef19e360 soot_coffi_InnerClasses__5fattribute
// @dep_class 49e6b7ec550acdca soot_coffi_attribute__5finfo
// @dep_class 56d32f88b284d84e soot_coffi_inner__5fclass__5fentry

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_lang_StringBuffer
// @dep_header soot_coffi_InnerClasses__5fattribute
// @dep_header soot_coffi_inner__5fclass__5fentry

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/lang/StringBuffer.h"
#include "soot/coffi/InnerClasses__5fattribute.h"
#include "soot/coffi/inner__5fclass__5fentry.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// public int inner_classes_length
static _jc_field _jc_soot_coffi_InnerClasses__5fattribute$field_info$inner__5fclasses__5flength = {
	.name=		"inner_classes_length",
	.signature=	"I",
	.class=		&_jc_soot_coffi_InnerClasses__5fattribute$type,
	.type=		&_jc_int$prim$type,
	.access_flags=	_JC_ACC_PUBLIC,
	.offset=	_JC_OFFSETOF(_jc_soot_coffi_InnerClasses__5fattribute$object, nonrefs.soot_coffi_InnerClasses__5fattribute.inner__5fclasses__5flength),
};

// public soot.coffi.inner_class_entry[] inner_classes
static _jc_field _jc_soot_coffi_InnerClasses__5fattribute$field_info$inner__5fclasses = {
	.name=		"inner_classes",
	.signature=	"[Lsoot/coffi/inner_class_entry;",
	.class=		&_jc_soot_coffi_InnerClasses__5fattribute$type,
	.type=		&_jc_soot_coffi_inner__5fclass__5fentry$array$type,
	.access_flags=	_JC_ACC_PUBLIC,
	.offset=	_JC_OFFSETOF(_jc_soot_coffi_InnerClasses__5fattribute$object, refs[-1].soot_coffi_InnerClasses__5fattribute.inner__5fclasses),
};

// Fields
static _jc_field *const _jc_soot_coffi_InnerClasses__5fattribute$fields[] = {
	&_jc_soot_coffi_InnerClasses__5fattribute$field_info$inner__5fclasses,
	&_jc_soot_coffi_InnerClasses__5fattribute$field_info$inner__5fclasses__5flength
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// void <init>()
//

static _jc_linenum _jc_soot_coffi_InnerClasses__5fattribute$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_soot_coffi_InnerClasses__5fattribute$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_soot_coffi_InnerClasses__5fattribute$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_soot_coffi_InnerClasses__5fattribute$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_soot_coffi_InnerClasses__5fattribute$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		0,
	.function=		&_jc_soot_coffi_InnerClasses__5fattribute$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_coffi_InnerClasses__5fattribute$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_coffi_InnerClasses__5fattribute, _init$52f4ad9f2989aeee);

void
_jc_soot_coffi_InnerClasses__5fattribute$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_soot_coffi_InnerClasses__5fattribute$object *this)
{
	struct _jc_soot_coffi_InnerClasses__5fattribute$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(41);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public java.lang.String toString()
//

static _jc_linenum _jc_soot_coffi_InnerClasses__5fattribute$linenum_table$toString$7ea43b33b80a3070[];

static const unsigned char _jc_soot_coffi_InnerClasses__5fattribute$param_ptypes$toString$7ea43b33b80a3070[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_soot_coffi_InnerClasses__5fattribute$method_info$toString$7ea43b33b80a3070 = {
	.name=			"toString",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_soot_coffi_InnerClasses__5fattribute$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_soot_coffi_InnerClasses__5fattribute$param_ptypes$toString$7ea43b33b80a3070,
	.signature_hash=	_JC_JLONG(0x7ea43b33b80a3070),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_coffi_InnerClasses__5fattribute$method$toString$7ea43b33b80a3070,
	.vtable_index=		_JC_OFFSETOF(struct _jc_soot_coffi_InnerClasses__5fattribute$vtable, soot_coffi_InnerClasses__5fattribute.toString$7ea43b33b80a3070) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	5,
	      .table=	_jc_soot_coffi_InnerClasses__5fattribute$linenum_table$toString$7ea43b33b80a3070
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_coffi_InnerClasses__5fattribute, toString$7ea43b33b80a3070);

_jc_java_lang_String$object *
_jc_soot_coffi_InnerClasses__5fattribute$method$toString$7ea43b33b80a3070(_jc_env *const env, _jc_soot_coffi_InnerClasses__5fattribute$object *this)
{
	jint i0;
	jint i1;
	struct _jc_soot_coffi_InnerClasses__5fattribute$object *r0;
	struct _jc_java_lang_StringBuffer$object *r1;
	_jc_object_array *r2;
	struct _jc_soot_coffi_inner__5fclass__5fentry$object *r3;
	struct _jc_java_lang_String$object *r4;
	_jc_char_array *r5;
	struct _jc_java_lang_String$object *r8;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	_JC_LINE_NUMBER(49);				// 0
	r1 = _JC_NEW(env, java_lang_StringBuffer);
	r5 = _JC_NEW_PRIM_ARRAY(env, char, 1, 16);
	_JC_REF_FIELD(env, r1, java_lang_StringBuffer, value) = r5;
	_JC_LINE_NUMBER(50);				// 1
	i0 = 0;
	goto label3;

label0:
	_JC_LINE_NUMBER(51);				// 2
	r2 = _JC_REF_FIELD(env, r0, soot_coffi_InnerClasses__5fattribute, inner__5fclasses);
	r3 = _JC_REF_ELEMENT(env, r2, i0, 0, 1);
	if (r3 != _JC_NULL)
		goto label1;
	r8 = _JC_STRING(env, "null");
	goto label2;

label1:
	r8 = _JC_INVOKE_VIRTUAL(env, java_lang_Object, toString$7ea43b33b80a3070, r3);

label2:
	_JC_INVOKE_NONVIRTUAL(env, java_lang_StringBuffer, append$7d7ff98bb1f0cb55, 0, r1, r8);
	_JC_INVOKE_NONVIRTUAL(env, java_lang_StringBuffer, append$9450b16e89f0618d, 0, r1, 10);
	_JC_LINE_NUMBER(50);				// 3
	i0 = i0 + 1;

label3:
	i1 = _JC_PRIM_FIELD(env, r0, soot_coffi_InnerClasses__5fattribute, inner__5fclasses__5flength);
	if (i0 < i1) {
		_JC_PERIODIC_CHECK(env);
		goto label0;
	}
	r4 = _JC_NEW(env, java_lang_String);
	_JC_INVOKE_NONVIRTUAL(env, java_lang_String, _init$aa54f0755ac8f3ce, 0, r4, r1);
	_JC_LINE_NUMBER(54);				// 4
	return r4;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_soot_coffi_InnerClasses__5fattribute$methods[] = {
	&_jc_soot_coffi_InnerClasses__5fattribute$method_info$_init$52f4ad9f2989aeee,
	&_jc_soot_coffi_InnerClasses__5fattribute$method_info$toString$7ea43b33b80a3070
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_soot_coffi_InnerClasses__5fattribute$instanceof_hash_bucket_74[] = {
	&_jc_soot_coffi_attribute__5finfo$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_coffi_InnerClasses__5fattribute$instanceof_hash_bucket_96[] = {
	&_jc_soot_coffi_InnerClasses__5fattribute$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_coffi_InnerClasses__5fattribute$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_soot_coffi_InnerClasses__5fattribute$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[74]=	_jc_soot_coffi_InnerClasses__5fattribute$instanceof_hash_bucket_74,
	[96]=	_jc_soot_coffi_InnerClasses__5fattribute$instanceof_hash_bucket_96,
	[113]=	_jc_soot_coffi_InnerClasses__5fattribute$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_soot_coffi_InnerClasses__5fattribute$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "java/lang/StringBuffer",	_JC_JLONG(0x94d357637b968dda) },
	{ "soot/coffi/attribute_info",	_JC_JLONG(0x49e6b7ec550acdca) },
	{ "soot/coffi/inner_class_entry",	_JC_JLONG(0x56d32f88b284d84e) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_soot_coffi_InnerClasses__5fattribute$vtype _jc_soot_coffi_InnerClasses__5fattribute$type = {
    .type= {
	.name=			"soot/coffi/InnerClasses_attribute",
	.superclass=		&_jc_soot_coffi_attribute__5finfo$type,
	.access_flags=		0,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		12,
		.hash=			_JC_JLONG(0x2910858fef19e360),
		.source_file=		"InnerClasses_attribute.java",
		.instance_size=		sizeof(_jc_soot_coffi_InnerClasses__5fattribute$refs) + sizeof(_jc_soot_coffi_InnerClasses__5fattribute$object),
		.num_virtual_refs=	1,
		.num_fields=		sizeof(_jc_soot_coffi_InnerClasses__5fattribute$fields) / sizeof(*_jc_soot_coffi_InnerClasses__5fattribute$fields),
		.fields=		_jc_soot_coffi_InnerClasses__5fattribute$fields,
		.num_methods=		sizeof(_jc_soot_coffi_InnerClasses__5fattribute$methods) / sizeof(*_jc_soot_coffi_InnerClasses__5fattribute$methods),
		.methods=		_jc_soot_coffi_InnerClasses__5fattribute$methods,
		.instanceof_hash_table=	_jc_soot_coffi_InnerClasses__5fattribute$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_soot_coffi_InnerClasses__5fattribute$class_depends) / sizeof(*_jc_soot_coffi_InnerClasses__5fattribute$class_depends),
		.class_depends=		_jc_soot_coffi_InnerClasses__5fattribute$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_soot_coffi_InnerClasses__5fattribute$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.soot_coffi_attribute__5finfo= {
	},
	.soot_coffi_InnerClasses__5fattribute= {
	    .toString$7ea43b33b80a3070=
		&_jc_soot_coffi_InnerClasses__5fattribute$method$toString$7ea43b33b80a3070,
	},
    }
};

==> jc-1.4.5.tar.gz: soot/coffi/InnerClasses__5fattribute.c <==
// class soot.coffi.InnerClasses_attribute

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 94d357637b968dda java_lang_StringBuffer
// @dep_class 2910858fef19e360 soot_coffi_InnerClasses__5fattribute
// @dep_class 49e6b7ec550acdca soot_coffi_attribute__5finfo
// @dep_class 56d32f88b284d84e soot_coffi_inner__5fclass__5fentry

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_lang_StringBuffer
// @dep_header soot_coffi_InnerClasses__5fattribute
// @dep_header soot_coffi_inner__5fclass__5fentry

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/lang/StringBuffer.h"
#include "soot/coffi/InnerClasses__5fattribute.h"
#include "soot/coffi/inner__5fclass__5fentry.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// public int inner_classes_length
static _jc_field _jc_soot_coffi_InnerClasses__5fattribute$field_info$inner__5fclasses__5flength = {
	.name=		"inner_classes_length",
	.signature=	"I",
	.class=		&_jc_soot_coffi_InnerClasses__5fattribute$type,
	.type=		&_jc_int$prim$type,
	.access_flags=	_JC_ACC_PUBLIC,
	.offset=	_JC_OFFSETOF(_jc_soot_coffi_InnerClasses__5fattribute$object, nonrefs.soot_coffi_InnerClasses__5fattribute.inner__5fclasses__5flength),
};

// public soot.coffi.inner_class_entry[] inner_classes
static _jc_field _jc_soot_coffi_InnerClasses__5fattribute$field_info$inner__5fclasses = {
	.name=		"inner_classes",
	.signature=	"[Lsoot/coffi/inner_class_entry;",
	.class=		&_jc_soot_coffi_InnerClasses__5fattribute$type,
	.type=		&_jc_soot_coffi_inner__5fclass__5fentry$array$type,
	.access_flags=	_JC_ACC_PUBLIC,
	.offset=	_JC_OFFSETOF(_jc_soot_coffi_InnerClasses__5fattribute$object, refs[-1].soot_coffi_InnerClasses__5fattribute.inner__5fclasses),
};

// Fields
static _jc_field *const _jc_soot_coffi_InnerClasses__5fattribute$fields[] = {
	&_jc_soot_coffi_InnerClasses__5fattribute$field_info$inner__5fclasses,
	&_jc_soot_coffi_InnerClasses__5fattribute$field_info$inner__5fclasses__5flength
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// void <init>()
//

static _jc_linenum _jc_soot_coffi_InnerClasses__5fattribute$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_soot_coffi_InnerClasses__5fattribute$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_soot_coffi_InnerClasses__5fattribute$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_soot_coffi_InnerClasses__5fattribute$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_soot_coffi_InnerClasses__5fattribute$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		0,
	.function=		&_jc_soot_coffi_InnerClasses__5fattribute$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_coffi_InnerClasses__5fattribute$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_coffi_InnerClasses__5fattribute, _init$52f4ad9f2989aeee);

void _JC_JCNI_ATTR
_jc_soot_coffi_InnerClasses__5fattribute$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_soot_coffi_InnerClasses__5fattribute$object *this)
{
	struct _jc_soot_coffi_InnerClasses__5fattribute$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(41);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public java.lang.String toString()
//

static _jc_linenum _jc_soot_coffi_InnerClasses__5fattribute$linenum_table$toString$7ea43b33b80a3070[];

static const unsigned char _jc_soot_coffi_InnerClasses__5fattribute$param_ptypes$toString$7ea43b33b80a3070[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_soot_coffi_InnerClasses__5fattribute$method_info$toString$7ea43b33b80a3070 = {
	.name=			"toString",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_soot_coffi_InnerClasses__5fattribute$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_soot_coffi_InnerClasses__5fattribute$param_ptypes$toString$7ea43b33b80a3070,
	.signature_hash=	_JC_JLONG(0x7ea43b33b80a3070),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_coffi_InnerClasses__5fattribute$method$toString$7ea43b33b80a3070,
	.vtable_index=		_JC_OFFSETOF(struct _jc_soot_coffi_InnerClasses__5fattribute$vtable, soot_coffi_InnerClasses__5fattribute.toString$7ea43b33b80a3070) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	5,
	      .table=	_jc_soot_coffi_InnerClasses__5fattribute$linenum_table$toString$7ea43b33b80a3070
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_coffi_InnerClasses__5fattribute, toString$7ea43b33b80a3070);

_jc_java_lang_String$object * _JC_JCNI_ATTR
_jc_soot_coffi_InnerClasses__5fattribute$method$toString$7ea43b33b80a3070(_jc_env *const env, _jc_soot_coffi_InnerClasses__5fattribute$object *this)
{
	jint i0;
	jint i1;
	struct _jc_soot_coffi_InnerClasses__5fattribute$object *r0;
	struct _jc_java_lang_StringBuffer$object *r1;
	_jc_object_array *r2;
	struct _jc_soot_coffi_inner__5fclass__5fentry$object *r3;
	struct _jc_java_lang_String$object *r4;
	_jc_char_array *r5;
	struct _jc_java_lang_String$object *r8;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	_JC_LINE_NUMBER(49);				// 0
	r1 = _JC_NEW(env, java_lang_StringBuffer);
	r5 = _JC_NEW_PRIM_ARRAY(env, char, 1, 16);
	_JC_REF_FIELD(env, r1, java_lang_StringBuffer, value) = r5;
	_JC_LINE_NUMBER(50);				// 1
	i0 = 0;
	goto label3;

label0:
	_JC_LINE_NUMBER(51);				// 2
	r2 = _JC_REF_FIELD(env, r0, soot_coffi_InnerClasses__5fattribute, inner__5fclasses);
	r3 = _JC_REF_ELEMENT(env, r2, i0, 0, 1);
	if (r3 != _JC_NULL)
		goto label1;
	r8 = _JC_STRING(env, "null");
	goto label2;

label1:
	r8 = _JC_INVOKE_VIRTUAL(env, java_lang_Object, toString$7ea43b33b80a3070, r3);

label2:
	_JC_INVOKE_NONVIRTUAL(env, java_lang_StringBuffer, append$7d7ff98bb1f0cb55, 0, r1, r8);
	_JC_INVOKE_NONVIRTUAL(env, java_lang_StringBuffer, append$9450b16e89f0618d, 0, r1, 10);
	_JC_LINE_NUMBER(50);				// 3
	i0 = i0 + 1;

label3:
	i1 = _JC_PRIM_FIELD(env, r0, soot_coffi_InnerClasses__5fattribute, inner__5fclasses__5flength);
	if (i0 < i1) {
		_JC_PERIODIC_CHECK(env);
		goto label0;
	}
	r4 = _JC_NEW(env, java_lang_String);
	_JC_INVOKE_NONVIRTUAL(env, java_lang_String, _init$aa54f0755ac8f3ce, 0, r4, r1);
	_JC_LINE_NUMBER(54);				// 4
	return r4;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_soot_coffi_InnerClasses__5fattribute$methods[] = {
	&_jc_soot_coffi_InnerClasses__5fattribute$method_info$_init$52f4ad9f2989aeee,
	&_jc_soot_coffi_InnerClasses__5fattribute$method_info$toString$7ea43b33b80a3070
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_soot_coffi_InnerClasses__5fattribute$instanceof_hash_bucket_74[] = {
	&_jc_soot_coffi_attribute__5finfo$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_coffi_InnerClasses__5fattribute$instanceof_hash_bucket_96[] = {
	&_jc_soot_coffi_InnerClasses__5fattribute$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_coffi_InnerClasses__5fattribute$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_soot_coffi_InnerClasses__5fattribute$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[74]=	_jc_soot_coffi_InnerClasses__5fattribute$instanceof_hash_bucket_74,
	[96]=	_jc_soot_coffi_InnerClasses__5fattribute$instanceof_hash_bucket_96,
	[101]=	_jc_soot_coffi_InnerClasses__5fattribute$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_soot_coffi_InnerClasses__5fattribute$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "java/lang/StringBuffer",	_JC_JLONG(0x94d357637b968dda) },
	{ "soot/coffi/attribute_info",	_JC_JLONG(0x49e6b7ec550acdca) },
	{ "soot/coffi/inner_class_entry",	_JC_JLONG(0x56d32f88b284d84e) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_soot_coffi_InnerClasses__5fattribute$vtype _jc_soot_coffi_InnerClasses__5fattribute$type = {
    .type= {
	.name=			"soot/coffi/InnerClasses_attribute",
	.superclass=		&_jc_soot_coffi_attribute__5finfo$type,
	.access_flags=		0,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		12,
		.hash=			_JC_JLONG(0x2910858fef19e360),
		.source_file=		"InnerClasses_attribute.java",
		.instance_size=		sizeof(_jc_soot_coffi_InnerClasses__5fattribute$refs) + sizeof(_jc_soot_coffi_InnerClasses__5fattribute$object),
		.num_virtual_refs=	1,
		.num_fields=		sizeof(_jc_soot_coffi_InnerClasses__5fattribute$fields) / sizeof(*_jc_soot_coffi_InnerClasses__5fattribute$fields),
		.fields=		_jc_soot_coffi_InnerClasses__5fattribute$fields,
		.num_methods=		sizeof(_jc_soot_coffi_InnerClasses__5fattribute$methods) / sizeof(*_jc_soot_coffi_InnerClasses__5fattribute$methods),
		.methods=		_jc_soot_coffi_InnerClasses__5fattribute$methods,
		.instanceof_hash_table=	_jc_soot_coffi_InnerClasses__5fattribute$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_soot_coffi_InnerClasses__5fattribute$class_depends) / sizeof(*_jc_soot_coffi_InnerClasses__5fattribute$class_depends),
		.class_depends=		_jc_soot_coffi_InnerClasses__5fattribute$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_soot_coffi_InnerClasses__5fattribute$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.soot_coffi_attribute__5finfo= {
	},
	.soot_coffi_InnerClasses__5fattribute= {
	    .toString$7ea43b33b80a3070=
		&_jc_soot_coffi_InnerClasses__5fattribute$method$toString$7ea43b33b80a3070,
	},
    }
};
